function [G_lin sig] = calc_prop_hex(U, N, cell_radius, exclude_disk_radius, f_c, terminal_height, BS_height, Grx, Gtx, shadow_dev)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   Script to calculate propagation.        %
%   Model N neighboring HEXAGONAL cells     %
%   Author: Anders Gjendemsj, IET, NTNU.   %
%   Email: gjendems@iet.ntnu.no             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%
% Defining variables.    %
%%%%%%%%%%%%%%%%%%%%%%%%%%

a_terminal_small_med =(1.1 * log10(f_c) - .7)*terminal_height - (1.56*log10(f_c) - .8); % in dB, small, med cities.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% User locations.                                     %
% user_loc : N x U x 2 array                          %
% N - cell index. U - number of users in each cell.   %
% 2-> x,y coord.                                      %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
user_loc = zeros(N,U,2);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Distance from user u in cell n to BS in cell "all" n.  %
% dist_user_BS_cell : N x U x N array                    %
% N - cell index. U - number of users in each cell.      %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
dist_user_BS_cell = zeros(N,U,N);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Channel power gains.                                %
% G_lin / G_dB :  N x N x U  array                    %
% N - cell index. U - number of users in each cell.   %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
G_lin = zeros(N,N,U);
G_dB = zeros(N,N,U);



%Locate N cells, coordinate axes with 0,0 in center of cell one.
%So far, only valid for up to 7 cells.
BS_location = [0, 0;...
              (3/2)*cell_radius,  -(sqrt(3)/2)*cell_radius;...
              (3/2)*cell_radius,  (sqrt(3)/2)*cell_radius;...
               0,                 sqrt(3)*cell_radius;...
              -(3/2)*cell_radius, (sqrt(3)/2)*cell_radius;...
              -(3/2)*cell_radius, -(sqrt(3)/2)*cell_radius;...
              0,                  -sqrt(3)*cell_radius];
BS_location = BS_location(1:N,:); %Take out the N-cells we want. NB! N<= 7.


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Generate users location, uniform over each cell. %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
x = cell_radius * rand(N,U);       % Create x uniform in (0,R).
y = (rand(N,U)-0.5)*2*cell_radius;           % Create y uniform in (-R,R).

%Split the square (0,0 -> R,R) into two similar right trapezoids.
%Use logicals to avoid for loop.
IND = abs(y) + 3*x > 2*cell_radius; 
x(IND) = x(IND) - cell_radius;
y(IND) = sign(y(IND))*cell_radius - y(IND);

%Scale to fit the hexagon(s).
x = x * (3/2);
y = y * sqrt(3)/2;

%Exclude disk in the center.
while any(any(sqrt(x.^2 + y.^2) < exclude_disk_radius))
    IND = sqrt(x.^2 + y.^2) < exclude_disk_radius;
    ssIND= sum(sum(IND));
    newXvals = zeros(1,ssIND);
    newYvals = zeros(1,ssIND);
    %Re-draw
    newXvals = (cell_radius * rand(ssIND,1));
    newYvals = (rand(ssIND,1)-0.5)*2*cell_radius;
    IND2 = abs(newYvals) + 3*newXvals > 2*cell_radius;
       
    
    newXvals(IND2) = newXvals(IND2) - cell_radius;
    newYvals(IND2) = sign(newYvals(IND2))*cell_radius - newYvals(IND2);
    %Scale.
    newXvals = newXvals * 3/2;
    newYvals = newYvals * sqrt(3)/2;
    x(IND) = newXvals; 
    y(IND) = newYvals;
end
%INDCheck = sqrt(x.^2 + y.^2) < exclude_disk_radius;
k
%Locate in cells, i.e., Array NxUx2.
user_loc_cell(:,:,1) = repmat(BS_location(:,1),1,U) + x;  %x coordinate
user_loc_cell(:,:,2) = repmat(BS_location(:,2),1,U) + y;  %y coordinate

% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% % Scatter plot of user location.  %
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% figure(1);
% hold off;
% scatter(user_loc_cell(1,:,1), user_loc_cell(1,:,2));
% hold on;
% for n=2:N
%     scatter(user_loc_cell(n,:,1), user_loc_cell(n,:,2));
% end
% % % hold on;
% % % scatter(user_loc_cell_2(1,:),user_loc_cell_2(2,:),'k');
% % % %axis([-1000 3000 -2000 2000]);
% title('Scatter plot of user location.');
% 
% pause;

%%Cell 1
%user_loc_cell_1(1,:) = x(1:U1).*(3/2); %x coordinate
%user_loc_cell_1(2,:) = y(1:U1).*sqrt(3/4); %y coordinate

%Cell 2
%user_loc_cell_2(1,:) = BS2_location(1) + x(U1+1:end)*(3/2); %x coordinate
%user_loc_cell_2(2,:) = BS2_location(2) + y(U1+1:end)*sqrt(3/4); %y coordinate

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Distance from user u in cell n to BS in cell "all" n.  %
% dist_user_BS_cell : N x U x N array                    %
% N - cell index. U - number of users in each cell.      %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Distance for users in cell 1 to BS 1 (row 1) and BS 2 (row 2).
%BS_loc = repmat(BS_location(1,1),N,U)
%pause;

for n=1:N
    dist_user_BS_cell(1:N,1:U,n) = sqrt( (user_loc_cell(:,:,1) - repmat(BS_location(n,1),N,U) ).^2 ...
                                        +(user_loc_cell(:,:,2) - repmat(BS_location(n,2),N,U) ).^2 );
end

%dist_user_bs_cell_1(2,:) = sqrt( (user_loc_cell_1(1,:) - BS2_location(1) ).^2 ...
%                                 +(user_loc_cell_1(2,:) - BS2_location(2) ).^2 );%To other base station.
%                             

% %Distance for users in cell 2 to BS 1 (row 1) and BS 2 (row 2).
%dist_user_bs_cell_2(1,:) = sqrt( (user_loc_cell_2(1,:) - BS1_location(1) ).^2 ...
%                                 +(user_loc_cell_2(2,:) - BS1_location(2) ).^2 );%To other base station.
%dist_user_bs_cell_2(2,:) = sqrt( (user_loc_cell_2(1,:) - BS2_location(1) ).^2 ...
%                                 +(user_loc_cell_2(2,:) - BS2_location(2) ).^2 );%To own base station.

                                
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Generate channel gains.                                    %
% For each user, the gain to the N stations.                 %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%PL_user_cell_1(1,:) = propagation_model( dist_user_bs_cell_1(1,:) ); %Wanted communication links.
%PL_user_cell_1(2,:) = propagation_model( dist_user_bs_cell_1(2,:) ); %Interference links.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Channel power gains.                                %
% G_lin / G_dB :  N x N x U  array                    %
% N - cell index. U - number of users in each cell.   %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% for u=1:U
%     G_dB(1:N,1:N,u) = - propagation_model( dist_user_BS_cell(1:N,u,1:N),a_terminal_small_med) + Grx + Gtx; %Wanted communication links.
% %G_cell_1_dB(1,:) = - propagation_model( dist_user_bs_cell_1(1,:) ) + Grx + Gtx; %Wanted communication links.
% %G_cell_1_dB(2,:) = - propagation_model( dist_user_bs_cell_1(2,:) ) + Grx + Gtx; %Interference links.
% end
% 
% %G_cell_2_dB(1,:) = - propagation_model( dist_user_bs_cell_2(1,:) ) + Grx + Gtx; %Interference links.
% %G_cell_2_dB(2,:) = - propagation_model( dist_user_bs_cell_2(2,:) ) + Grx + Gtx; %Wanted communication links.
% 
% %Add Rayleigh fading, powers will be exp. dist, add shadowing.
% %G_dB = 10*log10( exprnd( 10.^(G_dB./10) ) ) + normrnd(0,shadow_dev, N, N,U);
% %Alternative without stats toolbox.
% G_dB = 10*log10( -10.^(G_dB./10) .* log(rand(size(G_dB))) ) + randn( size(G_dB) ) .* shadow_dev;
% 
% %G_cell_1_dB = 10*log10( exprnd( 10.^(G_cell_1_dB./10) ) ) + normrnd(0,shadow_dev, 2, U1);
% %G_cell_2_dB = 10*log10( exprnd( 10.^(G_cell_2_dB./10) ) ) + normrnd(0,shadow_dev, 2, U2);
% 
% %Shadowing only.
% %G_cell_1_dB = G_cell_1_dB + normrnd(0,shadow_dev, 2, U1);
% %G_cell_2_dB = G_cell_2_dB + normrnd(0,shadow_dev, 2, U2);
% 
% 
% 
% %Convert to linear scale.
% G_lin = 10.^(G_dB./10);
% 
% 
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% % Calculate noise levels, sigma_1 and sigma_2 %
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% boltz_const = 1.3806503*10^(-23);
% T_0 = 290;                                  % ambient temperature in kelvins
% B = 1*10^(6);                               % equivalent bandwidth 1MHz
% therm_noise_W = boltz_const*T_0*B;          % thermal noise power in W
% sig = ones(1,N)*therm_noise_W;
% %sig2 = therm_noise_W;
%  
% % %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% % %Calculate loss in dB, according to COST-231 model.    %
% % %See chapter 2.5.3, (p.38) in  Goldsmith's wireless    %
% % %comm book for reference.                              %
% % %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%         
%         %Cm = 0; % for medium sized cities and suburbs, 3 dB for metropolitian areas.
%     function path_loss = propagation_model(distance_user_bs, a_terminal_small_med)
%         %a_terminal = 3.2 * (log10(11.75*terminal_height))^2 - 4.97; %in dB, big cities.
% 
%         path_loss = 46.3 + 33.9 * log10(f_c) - 13.82 * log10(BS_height) - a_terminal_small_med ...
%            + (44.9-6.55*log10(BS_height))*log10(distance_user_bs/1000);% + Cm=0;
%        %path_loss = Loss_231; %in dB
%     end


% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% % Scatter plot of user location.  %
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure(1);
hold on;
for n=1:N
    scatter(user_loc_cell(n,:,1), user_loc_cell(n,:,2));
end
% % scatter(user_loc_cell_1(1,:),user_loc_cell_1(2,:));
% % hold on;
% % scatter(user_loc_cell_2(1,:),user_loc_cell_2(2,:),'k');
% % %axis([-1000 3000 -2000 2000]);
title('Scatter plot of user location.');

end