%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Script for presentation of        %
% simulation results for N cells.   %
% Author: Sigbj?rn Dybdahl          %   
% Last edited: 4. March 2007        %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all; close all; clc;

% Defining simulation parameters
P_max = 1;                  % maximum transmit power [W]
P_min1 = 0.1;               % minimum transmit power levels [W]
P_min2 = 0.2;
P_min3 = 0.3;
number_simulations=10000;
cells=2:7;
sti='simulation_results/r_1000/N';

avg_power_BIN0=zeros(1,6);
avg_power_BIN1=zeros(1,6);
avg_power_BIN2=zeros(1,6);
avg_power_BIN3=zeros(1,6);

sum_cap_BIN0=zeros(1,6);
sum_cap_BIN1=zeros(1,6);
sum_cap_BIN2=zeros(1,6);
sum_cap_BIN3=zeros(1,6);
sum_cap_FULL=zeros(1,6);

for j=2:7
    
    nysti=[sti, num2str(j), '/'];
    
    % Load simulation data
    load([nysti, 'sum_capacityBIN0.mat'], 'sum_capacityBIN0');
    load([nysti, 'sum_capacityBIN1.mat'], 'sum_capacityBIN1');
    load([nysti, 'sum_capacityBIN2.mat'], 'sum_capacityBIN2');
    load([nysti, 'sum_capacityBIN3.mat'], 'sum_capacityBIN3');
    load([nysti, 'sum_capacityFULL.mat'], 'sum_capacityFULL');
    
    load([nysti, 'powerAllocBIN0.mat'], 'powerAllocBIN0');
    load([nysti, 'powerAllocBIN1.mat'], 'powerAllocBIN1');
    load([nysti, 'powerAllocBIN2.mat'], 'powerAllocBIN2');
    load([nysti, 'powerAllocBIN3.mat'], 'powerAllocBIN3');
    
    % Process power allocation data
%     powerAllocBIN1=powerAllocBIN1*(P_max-P_min1)+P_min1;
%     powerAllocBIN2=powerAllocBIN2*(P_max-P_min2)+P_min2;
%     powerAllocBIN3=powerAllocBIN3*(P_max-P_min3)+P_min3;
    
    power_BIN0=sum(sum(powerAllocBIN0))/(j*number_simulations);
    power_BIN1=sum(sum(powerAllocBIN1))/(j*number_simulations);
    power_BIN2=sum(sum(powerAllocBIN2))/(j*number_simulations);
    power_BIN3=sum(sum(powerAllocBIN3))/(j*number_simulations);
    
    avg_power_BIN0(j-1)=power_BIN0;
    avg_power_BIN1(j-1)=power_BIN1;
    avg_power_BIN2(j-1)=power_BIN2;
    avg_power_BIN3(j-1)=power_BIN3;
    
    % Move simulation data to defined variables
    sum_cap_BIN0(j-1)=sum_capacityBIN0;
    sum_cap_BIN1(j-1)=sum_capacityBIN1;
    sum_cap_BIN2(j-1)=sum_capacityBIN2;
    sum_cap_BIN3(j-1)=sum_capacityBIN3;
    sum_cap_FULL(j-1)=sum_capacityFULL;
    
end

% Plot simulation results
figure(1);
plot(cells, sum_cap_FULL/number_simulations,'k');
hold on;
plot(cells, sum_cap_BIN0/number_simulations,'k--');
plot(cells, sum_cap_BIN1/number_simulations,'k-.');
plot(cells, sum_cap_BIN2/number_simulations,'k:');
hold off;
set(gca, 'XTick', cells);
xlabel('Cells');
ylabel('System capacity (bits/s/Hz)');
legend('Full power', 'P_{min}=0', 'P_{min}=0.1', 'P_{min}=0.2', 'Location', 'West');

figure(2);
plot(cells, (sum_cap_FULL./cells)/number_simulations,'k');
hold on;
plot(cells, (sum_cap_BIN0./cells)/number_simulations,'k--');
plot(cells, (sum_cap_BIN1./cells)/number_simulations,'k-.');
plot(cells, (sum_cap_BIN2./cells)/number_simulations,'k:');
plot(cells, (sum_cap_BIN3./cells)/number_simulations,'k:x');
hold off;
set(gca, 'XTick', cells);
xlabel('Cells');
ylabel('Cell capacity (bits/s/Hz)');
legend('Full power', 'P_{min}=0', 'P_{min}=0.1', 'P_{min}=0.2', 'P_{min}=0.3', 'Location', 'NorthEast');

% Plot difference between results in %
figure(3)
plot(cells, ((sum_cap_BIN0-sum_cap_FULL)./(sum_cap_BIN0-sum_cap_FULL))*100, 'k');
hold on;
plot(cells, ((sum_cap_BIN0-sum_cap_BIN1)./(sum_cap_BIN0-sum_cap_FULL))*100, 'k-.');
plot(cells, ((sum_cap_BIN0-sum_cap_BIN2)./(sum_cap_BIN0-sum_cap_FULL))*100, 'k:');
plot(cells, ((sum_cap_BIN0-sum_cap_BIN3)./(sum_cap_BIN0-sum_cap_FULL))*100, 'k:x');
hold off;
set(gca, 'XTick', cells);
xlabel('Cells');
ylabel('Normalized loss in cell capacity (%)');
legend('Full power', 'P_{min}=0.1', 'P_{min}=0.2', 'P_{min}=0.3', 'Location', 'NorthEast');
    
% Plot used W
figure(4)
plot(cells, avg_power_BIN0, 'k--');
hold on;
plot(cells, avg_power_BIN1, 'k-.');
plot(cells, avg_power_BIN2, 'k:');
plot(cells, avg_power_BIN3, 'k:x');
hold off;
set(gca, 'XTick', cells);
xlabel('Cells');
ylabel('Average cell power usage (W)');
legend('P_{min}=0', 'P_{min}=0.1', 'P_{min}=0.2', 'P_{min}=0.3', 'Location', 'East');

figure(5)
plot(cells, ((sum_cap_FULL./cells)/number_simulations), 'k');
hold on;
plot(cells, ((sum_cap_BIN0./cells)/number_simulations)./avg_power_BIN0, 'k--');
plot(cells, ((sum_cap_BIN1./cells)/number_simulations)./avg_power_BIN1, 'k-.');
plot(cells, ((sum_cap_BIN2./cells)/number_simulations)./avg_power_BIN2, 'k:');
plot(cells, ((sum_cap_BIN3./cells)/number_simulations)./avg_power_BIN3, 'k:x');
hold off;
set(gca, 'XTick', cells);
%set(gca, 'YTick', 2:14);
%axis([2 7 2 14]);
xlabel('Cells');
ylabel('Average cell capacity per used power (bits/s/Hz/W)');
legend('Full power', 'P_{min}=0', 'P_{min}=0.1', 'P_{min}=0.2', 'P_{min}=0.3', 'Location', 'East');