function [G_cell_1_lin G_cell_2_lin sig1 sig2] = calc_prop_hex(U1, U2, cell_radius, f_c, terminal_height, BS_height, Grx, Gtx, shadow_dev, exclude_disk_radius, K1, K2)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   Script to calculate propagation.        %
%   Model two neighboring HEXAGONAL cells   %
%   Author: Anders Gjendemsj?, IET, NTNU.   %
%   Email: gjendems@iet.ntnu.no             %
%                                           %
%   Modified by Sigbjorn Dybdahl            %
%   Last edited: 9. May 2007                %
%    -added exclude disc radius             %
%    -added Rician fading                   %
%    -added Walfisch-Ikegami path loss      %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%
% Defining variables.    %
%%%%%%%%%%%%%%%%%%%%%%%%%%

user_loc_cell_1 = zeros(2,U1);
user_loc_cell_2 = zeros(2,U2);

dist_user_bs_cell_1 = zeros(2,U1);
dist_user_bs_cell_2 = zeros(2,U2);

G_cell_1_lin = zeros(2,U1);
G_cell_2_lin = zeros(2,U2);
G_cell_1_dB =  zeros(2,U1);
G_cell_2_dB = zeros(2,U2);

%PL_user_cell_1_lin = zeros(2,U1);
%PL_user_cell_2_lin = zeros(2,U1);

%Locate two cells, coordinate axes with 0,0 in center of cell one.
%
BS1_location = [0 0];
BS2_location = [(3/2)*cell_radius -(sqrt(3)/2)*cell_radius];


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Generate users location, uniform over each cell. %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
x = cell_radius * rand(1,U1+U2);       % Create x uniform in (0,R).
y = (rand(1,U1+U2)-0.5)*2*cell_radius;           % Create y uniform in (-R,R).

%Split the square (0,0 -> R,R) into to similar right trapezoids.
%Use logicals to avoid for loop.
IND = abs(y) + 3*x > 2*cell_radius; 
x(IND) = x(IND) - cell_radius;
y(IND) = sign(y(IND))*cell_radius - y(IND);

% Scale
x = x.*(3/2); %x coordinate
y = y.*sqrt(3)/2; %y coordinate

%Exclude disk in the center.
while any(any(sqrt(x.^2 + y.^2) < exclude_disk_radius))
    IND = sqrt(x.^2 + y.^2) < exclude_disk_radius;
    ssIND= sum(sum(IND));
    newXvals = zeros(1,ssIND);
    newYvals = zeros(1,ssIND);
    %Re-draw coordinates
    newXvals = (cell_radius * rand(ssIND,1));           % uniform rand.dist
    newYvals = (rand(ssIND,1)-0.5)*2*cell_radius;

    IND2 = abs(newYvals) + 3*newXvals > 2*cell_radius;  % flip
    newXvals(IND2) = newXvals(IND2) - cell_radius;      
    newYvals(IND2) = sign(newYvals(IND2))*cell_radius - newYvals(IND2);
    %Scale.
    newXvals = newXvals * 3/2;
    newYvals = newYvals * sqrt(3)/2;
    %Substitute
    x(IND) = newXvals; 
    y(IND) = newYvals;
end

%Cell 1
user_loc_cell_1(1,:) = x(1:U1); %x coordinate
user_loc_cell_1(2,:) = y(1:U1); %y coordinate

%Cell 2
user_loc_cell_2(1,:) = BS2_location(1) + x(U1+1:end); %x coordinate
user_loc_cell_2(2,:) = BS2_location(2) + y(U1+1:end); %y coordinate

%Distance for users in cell 1 to BS 1 (row 1) and BS 2 (row 2).
dist_user_bs_cell_1(1,:) = sqrt( (user_loc_cell_1(1,:) - BS1_location(1) ).^2 ...
                                 +(user_loc_cell_1(2,:) - BS1_location(2) ).^2 );%To own base station.
dist_user_bs_cell_1(2,:) = sqrt( (user_loc_cell_1(1,:) - BS2_location(1) ).^2 ...
                                 +(user_loc_cell_1(2,:) - BS2_location(2) ).^2 );%To other base station.
%                             

% %Distance for users in cell 2 to BS 1 (row 1) and BS 2 (row 2).
dist_user_bs_cell_2(1,:) = sqrt( (user_loc_cell_2(1,:) - BS1_location(1) ).^2 ...
                                 +(user_loc_cell_2(2,:) - BS1_location(2) ).^2 );%To other base station.
dist_user_bs_cell_2(2,:) = sqrt( (user_loc_cell_2(1,:) - BS2_location(1) ).^2 ...
                                 +(user_loc_cell_2(2,:) - BS2_location(2) ).^2 );%To own base station.


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Generate channel gains.                                    %
% For each user, the gain to the two base stations.          %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%PL_user_cell_1(1,:) = propagation_model( dist_user_bs_cell_1(1,:) ); %Wanted communication links.
%PL_user_cell_1(2,:) = propagation_model( dist_user_bs_cell_1(2,:) ); %Interference links.

G_cell_1_dB(1,:) = - propagation_model( dist_user_bs_cell_1(1,:) ) + Grx + Gtx; %Wanted communication links.
G_cell_1_dB(2,:) = - propagation_model( dist_user_bs_cell_1(2,:) ) + Grx + Gtx; %Interference links.

G_cell_2_dB(1,:) = - propagation_model( dist_user_bs_cell_2(1,:) ) + Grx + Gtx; %Interference links.
G_cell_2_dB(2,:) = - propagation_model( dist_user_bs_cell_2(2,:) ) + Grx + Gtx; %Wanted communication links.

%Add Rayleigh fading, powers will be exp. dist, add shadowing.
%Alternative with statistics toolbox
%G_cell_1_dB = 10*log10( exprnd( 10.^(G_cell_1_dB./10) ) ) + normrnd(0,shadow_dev, 2, U1);
%G_cell_2_dB = 10*log10( exprnd( 10.^(G_cell_2_dB./10) ) ) + normrnd(0,shadow_dev, 2, U2);

%Alternative without statistics toolbox
% G_cell_1_dB = 10*log10( -10.^(G_cell_1_dB./10) .* log(rand(size(G_cell_1_dB))) ) + randn( size(G_cell_1_dB) ) .* shadow_dev;
% G_cell_2_dB = 10*log10( -10.^(G_cell_2_dB./10) .* log(rand(size(G_cell_2_dB))) ) + randn( size(G_cell_2_dB) ) .* shadow_dev;

%Add Rician fading, add shadowing
% s1=( mean(10.^(G_cell_1_dB./10),2) ./ (K1+1) )*ones(1,size(G_cell_1_dB,2)); % Mean received scattered power in cell 1
% s2=( mean(10.^(G_cell_2_dB./10),2) ./ (K2+1) )*ones(1,size(G_cell_2_dB,2)); % Mean received scattered power in cell 2
% 
% G_cell_1_dB = 10*log10( ricernd(10.^(G_cell_1_dB./10), s1) ) + randn( size(G_cell_1_dB) ) .* shadow_dev;
% G_cell_2_dB = 10*log10( ricernd(10.^(G_cell_2_dB./10), s2) ) + randn( size(G_cell_2_dB) ) .* shadow_dev;

%Making channel gains Rician distributed, add shadowing
% G_cell_1_dB = 10*log10( ricianPower(G_cell_1_dB, K1) ) + randn( size(G_cell_1_dB) ) .* shadow_dev;
% G_cell_2_dB = 10*log10( ricianPower(G_cell_2_dB, K1) ) + randn( size(G_cell_2_dB) ) .* shadow_dev;


%Shadowing only.
% G_cell_1_dB = G_cell_1_dB + normrnd(0,shadow_dev, 2, U1);
% G_cell_2_dB = G_cell_2_dB + normrnd(0,shadow_dev, 2, U2);

G_cell_1_dB = G_cell_1_dB + randn( size(G_cell_1_dB) ) .* shadow_dev;
G_cell_2_dB = G_cell_2_dB + randn( size(G_cell_2_dB) ) .* shadow_dev;

%Convert to linear scale.
G_cell_1_lin = 10.^(G_cell_1_dB./10);
G_cell_2_lin = 10.^(G_cell_2_dB./10);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Calculate noise levels, sigma_1 and sigma_2 %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
boltz_const = 1.3806503*10^(-23);
T_0 = 290;                                  % ambient temperature in kelvins
B = 1*10^(9);                               % equivalent bandwidth 1MHz
therm_noise_W = boltz_const*T_0*B;          % thermal noise power in W
sig1 = therm_noise_W;
sig2 = therm_noise_W;
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Calculate loss in dB, according to COST-231 model.    %
%See chapter 2.5.3, (p.38) in  Goldsmiths wireless     %
%comm book for %reference.                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%     function path_loss = propagation_model(distance_user_bs)
%         %a_terminal = 3.2 * (log10(11.75*terminal_height))^2 - 4.97; %in dB, big cities.
%         a_terminal_small_med =(1.1 * log10(f_c) - .7)*terminal_height - (1.56*log10(f_c) - .8); % in dB, small, med cities.
%         Cm = 0; % for medium sized cities and suburbs, 3 dB for metropolitian areas.
% 
%         path_loss = 46.3 + 33.9 * log10(f_c) - 13.82 * log10(BS_height) - a_terminal_small_med ...
%            + (44.9-6.55*log10(BS_height))*log10(distance_user_bs/1000) + Cm;
%        %path_loss = Loss_231; %in dB
%     end

    function path_loss = propagation_model(distance_user_bs)
        path_loss = 42.6 + 26*log10(distance_user_bs/1000) + 20*log10(f_c);
    end



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Scatter plot of user location.  %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% figure(1);
% hold off;
% scatter(user_loc_cell_1(1,:),user_loc_cell_1(2,:));
% hold on;
% scatter(user_loc_cell_2(1,:),user_loc_cell_2(2,:),'k');
% %axis([-1000 3000 -2000 2000]);
% title('Scatter plot of user location.');

end