%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Simulation script for 2 cells.   %
% Author: Anders Gjendemsj?        %
% Last edited: 23. February 2007   %
%       by Sigbj?rn Dybdahl        %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clc; clear all;

tic

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Defining simulation parameters %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
number_simulations = 100;

P_min = 0;
P_max = 1;

ic = 100;            % time horizon for PFS

Cell_users = 1:1:10;
%Cell_users = 1:2:9;
%Cell_users = 11:3:20
%Cell_users = 24:4:40;
%Cell_users = 44:4:60;

cell_radius = 1000;   % cell radius in meters.

f_c = 1800;           % carrier frequency in MHz
BS_height = 30;       % BS height in meters
terminal_height = 1;  % terminal height in meters
exclude_disc_radius = 20;
                      % exclude disc radius in meters

Gtx = 16;             % Tx antenna gain in dB
Grx = 6;              % Rx antenna gain in dB

shadow_dev = 10;      % St.dev of shadowing in dB.

K = 5;                % Rician K factor

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Internal variables.          %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
sum_capacity_max = zeros(1,length(Cell_users));
sum_capacity_full_pow = zeros(1,length(Cell_users));

sum_capacity_pfs = zeros(1,length(Cell_users));
sum_capacity_pfspow = zeros(1,length(Cell_users));
sum_capacity_kim_pfs = zeros(1,length(Cell_users));
sum_capacity_kim_pfspow = zeros(1,length(Cell_users));

avg_syst_cap_max = zeros(1,length(Cell_users));
avg_syst_cap_full_pow = zeros(1,length(Cell_users));

avg_syst_cap_pfs = zeros(1,length(Cell_users));
avg_syst_cap_pfspow = zeros(1,length(Cell_users));
avg_syst_cap_kim_pfs = zeros(1,length(Cell_users));
avg_syst_cap_kim_pfspow = zeros(1,length(Cell_users));

number_cand_max = zeros(length(Cell_users),3);
number_cand_pfspow = zeros(length(Cell_users),3);
number_cand_kim_pfspow = zeros(length(Cell_users),3);

freq_cand_max = zeros(length(Cell_users),3);
freq_cand_pfspow = zeros(length(Cell_users),3);
freq_cand_kim_pfspow = zeros(length(Cell_users),3);


for j = 1 : length(Cell_users)
% j=2;
    U1 = Cell_users(j);
    U2 = U1;
    
    T = ones(2,U1);
    Tp = ones(2,U1);
    Tk = ones(2,U1);
    Tkp = ones(2,U1);
    
    %cap1 = zeros(1,U1);
    %cap2 = zeros(1,U2);
    %cap3 = zeros(U1,U2);
    disp(' ');    disp(' ');
    disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%');
    disp('%Starting simulation with parameters:%');
    disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%');
    disp(['Number of simulations: ', num2str(number_simulations)]);
    disp(['# Users in cell 1: ', num2str(U1)]);
    disp(['# Users in cell 2: : ', num2str(U2)]);
    disp(['P_min: ', num2str(P_min)]);
    disp(['P_max: ', num2str(P_max)]);

    
    for i = 1 : number_simulations
        [G_cell_1 G_cell_2 sig1 sig2] = calc_prop_hex(U1, U2, cell_radius, f_c, terminal_height, BS_height, Grx, Gtx, shadow_dev,exclude_disc_radius, K);
        
        %%% Maximum capacity scheduling
        %For a given set of users, gains, match the optimal users and power levels.
        maxcap1_tmp=zeros(1,U1);
        maxcap2_tmp=zeros(1,U1);
        maxcap3_tmp=zeros(1,U1);
        maxind_tmp=zeros(3,U1);
        
        for u1 = 1 : U1
            [maxcap1_tmp(u1), maxind_tmp(1,u1)] = max(log2( 1 + (P_max*G_cell_1(1,u1))./(sig1+P_min*G_cell_1(2,u1))) + log2( 1 + (P_min*G_cell_2(2,:))./(sig2+P_max*G_cell_2(1,:))));
            [maxcap2_tmp(u1), maxind_tmp(2,u1)] = max(log2( 1 + (P_min*G_cell_1(1,u1))./(sig1+P_max*G_cell_1(2,u1))) + log2( 1 + (P_max*G_cell_2(2,:))./(sig2+P_min*G_cell_2(1,:))));         
            [maxcap3_tmp(u1), maxind_tmp(3,u1)] = max(log2( 1 + (P_max*G_cell_1(1,u1))./(sig1+P_max*G_cell_1(2,u1))) + log2( 1 + (P_max*G_cell_2(2,:))./(sig2+P_max*G_cell_2(1,:))));
        end

        [maxcap1, maxind(1)] = max(maxcap1_tmp);
        [maxcap2, maxind(2)] = max(maxcap2_tmp);
        [maxcap3, maxind(3)] = max(maxcap3_tmp);
        
        %Keep track of solutions
        [tmp_value, tmp_index] = max([maxcap1 maxcap2 maxcap3]);
        sum_capacity_max(j) = sum_capacity_max(j) + tmp_value;
        number_cand_max(j,tmp_index) = number_cand_max(j,tmp_index) + 1;
        
        maxuser1=maxind(tmp_index);
        maxuser2=maxind_tmp(tmp_index,maxuser1);
        
        
        %%% Full power allocation
        sum_capacity_full_pow(j) = sum_capacity_full_pow(j) + maxcap3;
    
        %%%%% Alt 1: V-PFS
        %%% Joint proportional fair scheduling without power control
        pfs_val=zeros(1,U1);
        pfs_ind=zeros(1,U1);
        
        % finding k* = argmax_k R_[k]/T_k[i]
        for u1 = 1 : U1
            [pfs_val(u1), pfs_ind(u1)] = max( log2( 1 + (P_max*G_cell_1(1,u1))./(sig1+P_max*G_cell_1(2,u1)))/T(1,u1) + log2( 1 + (P_max*G_cell_2(2,:))./(sig2+P_max*G_cell_2(1,:)))./T(2,:));
        end
        
        [tradcap, tradind] = max(pfs_val);
        pfs_user1=tradind;
        pfs_user2=pfs_ind(tradind);
        
        %rate calculation
        rate=[log2( 1 + (P_max*G_cell_1(1,pfs_user1))./(sig1+P_max*G_cell_1(2,pfs_user1))), log2( 1 + (P_max*G_cell_2(2,pfs_user2))./(sig2+P_max*G_cell_2(1,pfs_user2)))];
        
%         vpfsaverage1=T(1,pfs_user1);
%         vpfsaverage2=T(2,pfs_user2);
%         gammelT=T;
        
        %updating T_k[i+1]
        T = (1-1/ic)*T;
        T(1,pfs_user1) = T(1,pfs_user1) + (1/ic)*rate(1);
        T(2,pfs_user2) = T(2,pfs_user2) + (1/ic)*rate(2);
        
        sum_capacity_pfs(j) = sum_capacity_pfs(j) + sum(rate);
        %cap_pfs(i,:) = rate;
        
%         vpfsuser1=pfs_user1;
%         vpfsuser2=pfs_user2;
%         vpfsvalue=tradcap;
%         vpfsrate=rate;
        
        %%% Joint proportional fair scheduling with power control
        % find the capacity for the different users
        pfscap_tmp=zeros(3,U1);
        pfscap_ind=zeros(3,U1);
        
        for u1 = 1 : U1
            [pfscap_tmp(1,u1), pfscap_ind(1,u1)] = max(log2( 1 + (P_max*G_cell_1(1,u1))./(sig1+P_min*G_cell_1(2,u1)))/Tp(1,u1) + log2( 1 + (P_min*G_cell_2(2,:))./(sig2+P_max*G_cell_2(1,:)))./Tp(2,:));
            [pfscap_tmp(2,u1), pfscap_ind(2,u1)] = max(log2( 1 + (P_min*G_cell_1(1,u1))./(sig1+P_max*G_cell_1(2,u1)))/Tp(1,u1) + log2( 1 + (P_max*G_cell_2(2,:))./(sig2+P_min*G_cell_2(1,:)))./Tp(2,:));         
            [pfscap_tmp(3,u1), pfscap_ind(3,u1)] = max(log2( 1 + (P_max*G_cell_1(1,u1))./(sig1+P_max*G_cell_1(2,u1)))/Tp(1,u1) + log2( 1 + (P_max*G_cell_2(2,:))./(sig2+P_max*G_cell_2(1,:)))./Tp(2,:));
        end

        [pfscap(1), pfsind(1)] = max(pfscap_tmp(1,:));
        [pfscap(2), pfsind(2)] = max(pfscap_tmp(2,:));
        [pfscap(3), pfsind(3)] = max(pfscap_tmp(3,:));
        
        %Keep track of solutions
        [tmp_value2, tmp_index2] = max(pfscap);
        
        user1=pfsind(tmp_index2);
        user2=pfscap_ind(tmp_index2,pfsind(tmp_index2)); 
        
        switch tmp_index2
            case 1
                cap=[log2( 1 + (P_max*G_cell_1(1,user1))./(sig1+P_min*G_cell_1(2,user1))), log2( 1 + (P_min*G_cell_2(2,user2))./(sig2+P_max*G_cell_2(1,user2)))];
            case 2
                cap=[log2( 1 + (P_min*G_cell_1(1,user1))./(sig1+P_max*G_cell_1(2,user1))), log2( 1 + (P_max*G_cell_2(2,user2))./(sig2+P_min*G_cell_2(1,user2)))];
            case 3
                cap=[log2( 1 + (P_max*G_cell_1(1,user1))./(sig1+P_max*G_cell_1(2,user1))), log2( 1 + (P_max*G_cell_2(2,user2))./(sig2+P_max*G_cell_2(1,user2)))];
        end
        
        tp_old(1) = Tp(1,pfs_user1);
        tp_old(2) = Tp(2,pfs_user2);
        
        % Update T_k[i+1]
        Tp = (1-1/ic)*Tp;
        Tp(1,user1) = Tp(1,user1) + (1/ic)*cap(1);
        Tp(2,user2) = Tp(2,user2) + (1/ic)*cap(2);
                
        
        sum_capacity_pfspow(j) = sum_capacity_pfspow(j) + sum(cap);
        number_cand_pfspow(j,tmp_index2) = number_cand_pfspow(j,tmp_index2) + 1;
        %cap_pfsp(i,:) = cap;
        
        %%%%% Alt 2 : Kim's paper
        %%% Joint proportional fair scheduling without power control
        pfs_val=zeros(1,U1);
        pfs_ind=zeros(1,U1);
        
        % finding k* = argmax_k R_[k]/T_k[i]
        for u1 = 1 : U1
            cell1 = 1 + log2( 1 + ( P_max*G_cell_1(1,u1) )./ (sig1+P_max*G_cell_1(2,u1) ) ) / ( (ic-1)*Tk(1,u1) ); 
            cell2 = 1 + log2( 1 + ( P_max*G_cell_2(2,:) )./ (sig1+P_max*G_cell_2(1,:) ) ) ./ ( (ic-1)*Tk(2,:) );
            [pfs_val(u1), pfs_ind(u1)] = max( cell1.*cell2 );
        end
        
        [tradcap, tradind] = max(pfs_val);
        pfs_user1=tradind;
        pfs_user2=pfs_ind(tradind);
        
        %rate calculation
        rate=[log2( 1 + (P_max*G_cell_1(1,pfs_user1))./(sig1+P_max*G_cell_1(2,pfs_user1))), log2( 1 + (P_max*G_cell_2(2,pfs_user2))./(sig2+P_max*G_cell_2(1,pfs_user2)))];
        
%         vpfsaverage1=T(1,pfs_user1);
%         vpfsaverage2=T(2,pfs_user2);
%         gammelT=T;
        
        %updating T_k[i+1]
        Tk = (1-1/ic)*Tk;
        Tk(1,pfs_user1) = Tk(1,pfs_user1) + (1/ic)*rate(1);
        Tk(2,pfs_user2) = Tk(2,pfs_user2) + (1/ic)*rate(2);
        
        sum_capacity_kim_pfs(j) = sum_capacity_kim_pfs(j) + sum(rate);
        %cap_pfs(i,:) = rate;
        
%         vpfsuser1=pfs_user1;
%         vpfsuser2=pfs_user2;
%         vpfsvalue=tradcap;
%         vpfsrate=rate;
        
        %%% Joint proportional fair scheduling with power control
        % find the capacity for the different users
        pfscap_tmp=zeros(3,U1);
        pfscap_ind=zeros(3,U1);
        
        for u1 = 1 : U1            
            cell1 = 1 + log2( 1 + ( P_max*G_cell_1(1,u1) )./ (sig1+P_min*G_cell_1(2,u1) ) ) / ( (ic-1)*Tkp(1,u1) ); 
            cell2 = 1 + log2( 1 + ( P_min*G_cell_2(2,:) )./ (sig1+P_max*G_cell_2(1,:) ) ) ./ ( (ic-1)*Tkp(2,:) );
            [pfscap_tmp(1,u1), pfscap_ind(1,u1)] = max( cell1.*cell2 );
            
            cell1 = 1 + log2( 1 + ( P_min*G_cell_1(1,u1) )./ (sig1+P_max*G_cell_1(2,u1) ) ) / ( (ic-1)*Tkp(1,u1) ); 
            cell2 = 1 + log2( 1 + ( P_max*G_cell_2(2,:) )./ (sig1+P_min*G_cell_2(1,:) ) ) ./ ( (ic-1)*Tkp(2,:) );
            [pfscap_tmp(2,u1), pfscap_ind(2,u1)] = max( cell1.*cell2 );
            
            cell1 = 1 + log2( 1 + ( P_max*G_cell_1(1,u1) )./ (sig1+P_max*G_cell_1(2,u1) ) ) / ( (ic-1)*Tkp(1,u1) ); 
            cell2 = 1 + log2( 1 + ( P_max*G_cell_2(2,:) )./ (sig1+P_max*G_cell_2(1,:) ) ) ./ ( (ic-1)*Tkp(2,:) );
            [pfscap_tmp(3,u1), pfscap_ind(3,u1)] = max( cell1.*cell2 );
            
%             [pfscap_tmp(1,u1), pfscap_ind(1,u1)] = max(log2( 1 + (P_max*G_cell_1(1,u1))./(sig1+P_min*G_cell_1(2,u1)))/Tkp(1,u1) + log2( 1 + (P_min*G_cell_2(2,:))./(sig2+P_max*G_cell_2(1,:)))./Tkp(2,:));
%             [pfscap_tmp(2,u1), pfscap_ind(2,u1)] = max(log2( 1 + (P_min*G_cell_1(1,u1))./(sig1+P_max*G_cell_1(2,u1)))/Tkp(1,u1) + log2( 1 + (P_max*G_cell_2(2,:))./(sig2+P_min*G_cell_2(1,:)))./Tkp(2,:));         
%             [pfscap_tmp(3,u1), pfscap_ind(3,u1)] = max(log2( 1 + (P_max*G_cell_1(1,u1))./(sig1+P_max*G_cell_1(2,u1)))/Tkp(1,u1) + log2( 1 + (P_max*G_cell_2(2,:))./(sig2+P_max*G_cell_2(1,:)))./Tkp(2,:));
        end

        [pfscap(1), pfsind(1)] = max(pfscap_tmp(1,:));
        [pfscap(2), pfsind(2)] = max(pfscap_tmp(2,:));
        [pfscap(3), pfsind(3)] = max(pfscap_tmp(3,:));
        
        %Keep track of solutions
        [tmp_value2, tmp_index2] = max(pfscap);
        
        user1=pfsind(tmp_index2);
        user2=pfscap_ind(tmp_index2,pfsind(tmp_index2)); 
        
        switch tmp_index2
            case 1
                cap=[log2( 1 + (P_max*G_cell_1(1,user1))./(sig1+P_min*G_cell_1(2,user1))), log2( 1 + (P_min*G_cell_2(2,user2))./(sig2+P_max*G_cell_2(1,user2)))];
            case 2
                cap=[log2( 1 + (P_min*G_cell_1(1,user1))./(sig1+P_max*G_cell_1(2,user1))), log2( 1 + (P_max*G_cell_2(2,user2))./(sig2+P_min*G_cell_2(1,user2)))];
            case 3
                cap=[log2( 1 + (P_max*G_cell_1(1,user1))./(sig1+P_max*G_cell_1(2,user1))), log2( 1 + (P_max*G_cell_2(2,user2))./(sig2+P_max*G_cell_2(1,user2)))];
        end
        
        % Update T_k[i+1]
        Tkp = (1-1/ic)*Tkp;
        Tkp(1,user1) = Tkp(1,user1) + (1/ic)*cap(1);
        Tkp(2,user2) = Tkp(2,user2) + (1/ic)*cap(2);
                
        
        sum_capacity_kim_pfspow(j) = sum_capacity_kim_pfspow(j) + sum(cap);
        number_cand_kim_pfspow(j,tmp_index2) = number_cand_kim_pfspow(j,tmp_index2) + 1;
        %cap_pfsp(i,:) = cap;

        
   
    end %for loop number of iterations.


    %%%%%%%%%%%%%%%%%%%%%%
    % Preparing results. %
    %%%%%%%%%%%%%%%%%%%%%%
    avg_syst_cap_max(j) = sum_capacity_max(j)/number_simulations;
    avg_syst_cap_full_pow(j) = sum_capacity_full_pow(j)/number_simulations;
    
    avg_syst_cap_pfs(j) = sum_capacity_pfs(j)/number_simulations;
    avg_syst_cap_pfspow(j) = sum_capacity_pfspow(j)/number_simulations;
    avg_syst_cap_kim_pfs(j) = sum_capacity_kim_pfs(j)/number_simulations;
    avg_syst_cap_kim_pfspow(j) = sum_capacity_kim_pfspow(j)/number_simulations;
    % number_cand
    
    freq_cand_max(j,:) = (number_cand_max(j,:)/number_simulations)*100;
    freq_cand_pfspow(j,:) = (number_cand_pfspow(j,:)/number_simulations)*100;
    freq_cand_kim_pfspow(j,:) = (number_cand_kim_pfspow(j,:)/number_simulations)*100;
    

    
    disp(' ');disp(' ');
    disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%');
    disp('%       Simulation finished!         %');
    disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%');

    %disp(['Sum_capacity: ', num2str(sum_capacity)]);
    disp(['Avg. system capacity, trad pfs: ', num2str(avg_syst_cap_pfs(j))]);
    disp(['Avg. system capacity, trad pfs pow.ad: ', num2str(avg_syst_cap_pfspow(j))]);
    disp(['Avg. system capacity, kim pfs: ', num2str(avg_syst_cap_kim_pfs(j))]);
    disp(['Avg. system capacity, kim pow.ad: ', num2str(avg_syst_cap_kim_pfspow(j))]);
    disp(['Avg. system capacity, max: ', num2str(avg_syst_cap_full_pow(j))]);
    disp(['Avg. system capacity, max pow.ad: ', num2str(avg_syst_cap_max(j))]);
    disp(['Frequency of solutions: ']);
    disp(['                 T-PFS      KIM-PFS      Max-Cap']);
    disp(['(P_max,P_min)    ',num2str(freq_cand_pfspow(j,1)),'      ',num2str(freq_cand_kim_pfspow(j,1)),'      ',num2str(freq_cand_max(j,1)),' %.']);
    disp(['(P_min,P_max)    ',num2str(freq_cand_pfspow(j,2)),'      ',num2str(freq_cand_kim_pfspow(j,2)),'      ',num2str(freq_cand_max(j,2)),' %.']);
    disp(['(P_max,P_max)    ',num2str(freq_cand_pfspow(j,3)),'      ',num2str(freq_cand_kim_pfspow(j,3)),'      ',num2str(freq_cand_max(j,3)),' %.']);
end

toc

%Store results

% directory = 'test/r_1000/p_min_0/';
% 
% save([directory, 'avg_syst_cap_pfs'], 'avg_syst_cap_pfs');
% save([directory, 'avg_syst_cap_pfspow'], 'avg_syst_cap_pfspow');
% save([directory, 'avg_syst_cap_kim_pfs'], 'avg_syst_cap_kim_pfs');
% save([directory, 'avg_syst_cap_kim_pfspow'], 'avg_syst_cap_kim_pfspow');
% save([directory, 'avg_syst_cap_full_pow'], 'avg_syst_cap_full_pow');
% save([directory, 'avg_syst_cap_max'], 'avg_syst_cap_max');
% 
% save([directory, 'freq_cand_pfspow'], 'freq_cand_pfspow');
% save([directory, 'freq_cand_kim_pfspow'], 'freq_cand_kim_pfspow');
% save([directory, 'freq_cand_max'], 'freq_cand_max');