%plot script.
%Anders Gjendemsj
%E-mail: gjendems@iet.ntnu.no

clc; clear all;

load simuleringer/avg_syst_cap avg_syst_cap;
load simuleringer/Cell_users Cell_users;
load simuleringer/freq_cand freq_cand;
load simuleringer/pow_vs_no_pow_2_cells_2_users;

number_cells = 2;

figure(1);
hold off;
plot(Cell_users, avg_syst_cap/number_cells,'k');
xlabel('Users per cell');
ylabel('System capacity (bits/s/Hz/Cell)');
axis([0 Cell_users(end) 5 16]);
grid on;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Frequency plot of solutions.  %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure(2);
hold off;
P_max_0_plot = plot(Cell_users, freq_cand(:,1),'k--');
hold on;
O_P_max_plot = plot(Cell_users, freq_cand(:,2),'k-.');
P_max_P_max_plot = plot(Cell_users, freq_cand(:,3),'k-');
ylabel('Frequency of solution in %.');
xlabel('Users per cell');
axis([0 Cell_users(end) 0 100]);
legend([P_max_0_plot, O_P_max_plot P_max_P_max_plot],'P_{max},0','0,P_{max}','P_{max},P_{max}','Location','Best');
grid on;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 3D-Plot showing solution at   %
% corner point.                 %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
cell_radius = 1000; f_c = 1800; BS_height = 30;
terminal_height = 1; Gtx = 6; Grx = 2; 
shadow_variance = 10;
U1=1; U2=1; P_max = 1;
rand('state',0);
randn('state',1);
[G_cell_1 G_cell_2 sig1 sig2] = calc_propagation(U1, U2, cell_radius, f_c, terminal_height, BS_height, Grx, Gtx, shadow_variance)
G = [G_cell_1(:,1) G_cell_2(:,1)]';
[P1,P2] = meshgrid(0:.05:P_max, 0:.05:P_max);
syst_cap = log2(1+(P1.*G(1,1))./(sig1+P2.*G(1,2)))+log2(1+(P2.*G(2,2))./(sig2+P1.*G(2,1)));
figure(3);
hold off;
colormap(zeros(64,3))

mesh(P1,P2,syst_cap);
XLABEL = xlabel('Transmit power at BS 1, P_1');
ylabel('Transmit power at BS 2, P_2');
zlabel('Sum throughput, R');

%%%%%%%%%%%%%%%%%%%%%%%
% Plot Pr(R<Abscissa) %
%%%%%%%%%%%%%%%%%%%%%%%
figure(4);
N_s = length(pow_vs_no_pow_2_cells_2_users);
Pr = zeros(1,N_s);
Pr = 1/N_s * (0:1:N_s);

hold off;
Pow_control_plot = plot([0 sort(pow_vs_no_pow_2_cells_2_users(1,:))], Pr,'k');
hold on;
Full_pow_plot = plot([0 sort(pow_vs_no_pow_2_cells_2_users(2,:))], Pr,'k--');
xlabel('Throughput in bits/s/Hz, R');
ylabel('Pr (R < Abscissa)');
axis([0 max(max(pow_vs_no_pow_2_cells_2_users)) 0 1]);
grid on;
legend([Pow_control_plot Full_pow_plot],'Power Control','Full Power',2);

%Exporting figures
%exportfig(figure(1),'../figurer/System_cap_vs_users.eps', 'width',10 ,'fontmode','fixed', 'fontsize',8);%'color','cmyk');
%exportfig(figure(2),'../figurer/Frequency_of_solutions.eps', 'width',10 ,'fontmode','fixed', 'fontsize',8);%'color','cmyk');
%exportfig(figure(3),'../figurer/System_cap_vs_powers.eps', 'width',10 ,'fontmode','fixed', 'fontsize',8);%'color','cmyk');
%exportfig(figure(4),'../figurer/Pr_less_abscissa.eps', 'width',10 ,'fontmode','fixed', 'fontsize',8);%'color','cmyk');
