clear
tic

%%%%%%%% cell parameters %%%%%%%%%%
U = 5;                                     % number of users per cell
R = 1000;                                   % Outer radius of cells in meters
N = 3;                                      % number of cells
K = 5;                                      % number of slots;
boltz_const = 1.3806503*10^(-23);
T_0 = 290;                                  % ambient temperature in kelvins
B = 1*10^(6);                               % equivalent bandwidth 1MHz
threshold = 1e+12
%%%%%%%%%%% Propagation parameters %%%%%%%%%%%%

maxBTStxPower_mW = 1000;
maxBTStxPower_dBm = 10*log10(maxBTStxPower_mW);                      % Max. BTS transmission power in dBm for 1 W

Gtx = 16;                                                % Tx antenna gain in dB
Grx = 6;                                                 % Rx antenna gain in dB
therm_noise_mW = boltz_const*T_0*B*1000;                 % thermal noise power in mW
therm_noise_dBm = 10*log10(therm_noise_mW);              % thermal noise power in dB

tx_pwr_dBm = maxBTStxPower_dBm*ones(U,N);

tar_SNR_dB = 30;       % in dB
tar_SNR = 10^(tar_SNR_dB/10);
tar_rx_pwr = tar_SNR*therm_noise_mW/1000;
%%%%%%%%%%% generate N cells %%%%%%%%%%%

[x,y,btsx,btsy] = big_cell_gen(U, R, N);        %returns users x(u,n) y(u,n) and BTS btsx(n) bts(n) caretsian coordinates

for  n = 1:N
    for u = 1:U
        for m = 1:N
            [userPathloss_dB(u,n,m),distUserBTS(u,n,m)] = propagation_model(x(u,n),y(u,n),btsx(m),btsy(m));      % pathloss between user(u,n) and BTS of every cell 
        end
    end
end


function [path_loss, distUserBTS] = propagation_model(x, y, bx, by)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% [path_loss, distUserBTS] = propagation_model(x, y, bx, by)
%
% Calculates path loss according to COST-231 model with zero mean and 10 dB
% variance log-normal shadowing between cartesian coordinates (x,y) and
% base station at coordinates (bx,by). distUserBTS is the scalar distance
% between the coordinates and the BTS. 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

f0 = 1800;      % carrier frequency in MHz
hb = 30;        % BS height in meters
hu = 1;         % terminal height in meters

X = normrnd(0,10);   %Gaussian distributed random variable mu = 0, vaiance = 10dB
% X=0;
distUserBTS = sqrt((x - bx)^2 + (y - by)^2);                       % distance between user and BTS of cell in meters
c_hr_smallmedcities = (1.1*log10(f0) - 0.7)*hu - (1.56*log10(f0) - 0.8);    % dB
c_hr_largecities = 3.2*(log10(11.75*hu))^2 - 4.97;                          % dB

Cm = 0;                                                                     % 3 dB in metrop. centers, 0 dB in medium sized cities and sub.areas
L_user = 46.3 + 33.9*log10(f0) - 13.82*log10(hb) - c_hr_smallmedcities + ...
    (44.9 - 6.55*log10(hb))*log10(distUserBTS/1000) + Cm;                     % COST-231 model for small medium city

path_loss = L_user + X;                                               %  adding shadowing factor
