function G_rician = ricianPower(G_cell_dB,K)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   Script to calculate Rician distributed  %
%   power envelope based on the model       %
%   developped at CMU (read notice below)   %
%   Author: Sigbjorn Dybdahl                %
%   Edited: 12. May 2007                    %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%  ***************************************************************************
%  *
%  *           Copyright 2000 by Carnegie Mellon University
%  * 
%  *                       All Rights Reserved
%  * 
%  * Permission to use, copy, modify, and distribute this software and its
%  * documentation for any purpose and without fee is hereby granted,
%  * provided that the above copyright notice appear in all copies and that
%  * both that copyright notice and this permission notice appear in
%  * supporting documentation, and that the name of CMU not be
%  * used in advertising or publicity pertaining to distribution of the
%  * software without specific, written prior permission.
%  * 
%  * CMU DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING
%  * ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL
%  * CMU BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR
%  * ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
%  * WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
%  * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
%  * SOFTWARE.
%  * 
%  * Author:  Ratish J. Punnoose
%  * 
%  ***************************************************************************

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Defining system parameters    %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
global rician;
total = size(rician,1);
[imax, jmax] = size(G_cell_dB);

selectionMatrix = total*ceil(rand(imax,jmax));
G_rician = zeros(imax,jmax);

G_cell = 10.^(G_cell_dB./10);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Performing envelope interpolation     %
% using Legendre polynomials            %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
for i = 1:imax
    for j = 1:jmax
        
        ind1 = selectionMatrix(i,j);
%         ind0 = mod(ind1-1+total,total);
%         ind2 = mod(ind1+1,total);
%         ind3 = mod(ind1+2,total);
%         
%         x1_inter = rician(ind0,1)*ind1*ind2*ind3/(-6) ...
%             + rician(ind1,1)*ind0*ind2*ind3/(0.5) ...
%             + rician(ind2,1)*ind0*ind1*ind3/(-0.5) ...
%             + rician(ind3,1)*ind0*ind1*ind2/(6);
%  
%         x2_inter = rician(ind0,2)*ind1*ind2*ind3/(-6) ...
%             + rician(ind1,2)*ind0*ind2*ind3/(0.5) ...
%             + rician(ind2,2)*ind0*ind1*ind3/(-0.5) ...
%             + rician(ind3,2)*ind0*ind1*ind2/(6);
% 
%         tmp_x1 = x1_inter + sqrt(2*K);
%         tmp_x2 = x2_inter;
        
        tmp_x1 = rician(ind1,1) + sqrt(2*K);
        tmp_x2 = rician(ind1,2);
        
        G_rician(i,j) = (tmp_x1^2 + tmp_x2^2) / (2*(K+1));        
        
    end
end

G_rician = G_cell .* G_rician;