%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Simulation script for 2 cells.   %
% Author: Anders Gjendemsj?        %
% Last edited: 23. February 2007   %
%       by Sigbj?rn Dybdahl        %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clc; clear all;

tic

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Defining simulation parameters %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
number_simulations = 10000;

P_min = 0;
P_max = 1;

Cell_users = 1:1:10;
%Cell_users = 1:2:9;
%Cell_users = 11:3:20
%Cell_users = 24:4:40;
%Cell_users = 44:4:60;



cell_radius = 1000;   % cell radius in meters.

f_c = 1800;           % carrier frequency in MHz
BS_height = 30;       % BS height in meters
terminal_height = 1;  % terminal height in meters
exclude_disc_radius = 20;
                      % exclude disc radius in meters

Gtx = 16;             % Tx antenna gain in dB
Grx = 6;              % Rx antenna gain in dB

shadow_dev = 10;      % St.dev of shadowing in dB.

K1 = 0;               % Rician K factors
K2 = 0;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Internal variables.          %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
sum_capacity = zeros(1,length(Cell_users));
sum_cap_full_pow = zeros(1,length(Cell_users));
number_cand = zeros(length(Cell_users),3);
freq_cand = zeros(length(Cell_users),3);
cand = zeros(1,3);

%For U1=U2=1
%capacity_1_1_pow_ad = zeros(1,number_simulations);
%capacity_1_1_full_pow = zeros(1,number_simulations);


for j = 1 : length(Cell_users)
    U1 = Cell_users(j);
    U2 = U1;
    %cap1 = zeros(1,U1);
    %cap2 = zeros(1,U2);
    %cap3 = zeros(U1,U2);
    disp(' ');    disp(' ');
    disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%');
    disp('%Starting simulation with parameters:%');
    disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%');
    disp(['Number of simulations: ', num2str(number_simulations)]);
    disp(['# Users in cell 1: ', num2str(U1)]);
    disp(['# Users in cell 2: : ', num2str(U2)]);
    disp(['P_min: ', num2str(P_min)]);
    disp(['P_max: ', num2str(P_max)]);

    
    for i = 1 : number_simulations
        [G_cell_1 G_cell_2 sig1 sig2] = calc_prop_hex(U1, U2, cell_radius, f_c, terminal_height, BS_height, Grx, Gtx, shadow_dev, exclude_disc_radius, K1, K2);
        
        %For a given set of users, gains, match the optimal users and power levels.
%         maxcap1 = max(log2( 1 + (P_max*G_cell_1(1,:))/sig1 ));
%         maxcap2 = max(log2( 1 + (P_max*G_cell_2(2,:))/sig2 ));
        maxcap1_tmp=zeros(1,U1);
        maxcap2_tmp=zeros(1,U1);
        maxcap3_tmp=zeros(1,U1);
        
        for u1 = 1 : U1
            maxcap1_tmp(u1) = max(log2( 1 + (P_max*G_cell_1(1,u1))./(sig1+P_min*G_cell_1(2,u1))) + log2( 1 + (P_min*G_cell_2(2,:))./(sig2+P_max*G_cell_2(1,:))));
            maxcap2_tmp(u1) = max(log2( 1 + (P_min*G_cell_1(1,u1))./(sig1+P_max*G_cell_1(2,u1))) + log2( 1 + (P_max*G_cell_2(2,:))./(sig2+P_min*G_cell_2(1,:))));         
            maxcap3_tmp(u1) = max(log2( 1 + (P_max*G_cell_1(1,u1))./(sig1+P_max*G_cell_1(2,u1))) + log2( 1 + (P_max*G_cell_2(2,:))./(sig2+P_max*G_cell_2(1,:))));
        end

        maxcap1 = max(maxcap1_tmp);
        maxcap2 = max(maxcap2_tmp);
        maxcap3 = max(maxcap3_tmp);
        
        %Keep track of solutions
        [tmp_value, tmp_index] = max([maxcap1 maxcap2 maxcap3]);
        sum_capacity(j) = sum_capacity(j) + tmp_value;
        sum_cap_full_pow(j) = sum_cap_full_pow(j) + maxcap3;
        
        number_cand(j,tmp_index) = number_cand(j,tmp_index) + 1;

        %For U1=U2=1, keep all solutions.
        %capacity_1_1_pow_ad(i) = tmp_value;
        %capacity_1_1_full_pow(i) = maxcap3;
        
        
   
    end %for loop number of iterations.


    % %%%%%%%%%%%%%%%%%%%%%%
    % % Preparing results. %
    % %%%%%%%%%%%%%%%%%%%%%%
    avg_syst_cap(j) = sum_capacity(j)/number_simulations;
    avg_syst_cap_full_pow(j) = sum_cap_full_pow(j)/number_simulations;
    % number_cand
    freq_cand(j,:) = (number_cand(j,:)/number_simulations)*100;
    % 
    % 
    disp(' ');disp(' ');
    disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%');
    disp('%       Simulation finished!         %');
    disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%');

    %disp(['Sum_capacity: ', num2str(sum_capacity)]);
    disp(['Avg. system capacity, full pow: ', num2str(avg_syst_cap_full_pow(j))]);
    disp(['Avg. system capacity, pow.ad: ', num2str(avg_syst_cap(j))]);
    disp(['Frequency of solutions: ']);
    disp(['(P_max,P_min)',num2str(freq_cand(j,1)),'%.']);
    disp(['(P_min,P_max)',num2str(freq_cand(j,2)),'%.']);
    disp(['(P_max,P_max)',num2str(freq_cand(j,3)),'%.']);
end

toc

%Store results

save simul_hex/high_snir/r_1000/p_min_0/sum_capacity sum_capacity;
save simul_hex/high_snir/r_1000/p_min_0/sum_cap_full_pow sum_cap_full_pow;
save simul_hex/high_snir/r_1000/p_min_0/freq_cand freq_cand;

% save simul_hex/p_min_02/rice_sum_capacity sum_capacity;
% save simul_hex/p_min_02/rice_sum_cap_full_pow sum_cap_full_pow;
% save simul_hex/p_min_02/rice_freq_cand freq_cand;

% save simul_hex/11_3_20/sum_capacity sum_capacity;
% save simul_hex/11_3_20/sum_cap_full_pow sum_cap_full_pow;
% save simul_hex/11_3_20/freq_cand freq_cand;

% save simul_hex/24_4_40/sum_capacity sum_capacity;
% save simul_hex/24_4_40/sum_cap_full_pow sum_cap_full_pow;
% save simul_hex/24_4_40/freq_cand freq_cand;

% save simul_hex/44_4_60/sum_capacity sum_capacity;
% save simul_hex/44_4_60/sum_cap_full_pow sum_cap_full_pow;
% save simul_hex/44_4_60/freq_cand freq_cand;

%For U1=U2=1
% save simul_hex/capacity_1_1_pow_ad capacity_1_1_pow_ad;
% save simul_hex/capacity_1_1_full_pow capacity_1_1_full_pow;
