%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Simulation script for 2 cells.   %
% Author: Anders Gjendemsj?        %
% Last edited: 23. February 2007   %
%       by Sigbj?rn Dybdahl        %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clc; clear all;

tic

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Defining simulation parameters %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
number_simulations = 10000;

P_min = 0;
P_max = 1;

ic = 100;            % time horizon for PFS

Cell_users = 1:1:10;
%Cell_users = 1:2:9;
%Cell_users = 11:3:20
%Cell_users = 24:4:40;
%Cell_users = 44:4:60;

cell_radius = 1000;   % cell radius in meters.

f_c = 1800;           % carrier frequency in MHz
BS_height = 30;       % BS height in meters
terminal_height = 1;  % terminal height in meters
exclude_disc_radius = 20;
                      % exclude disc radius in meters

Gtx = 16;             % Tx antenna gain in dB
Grx = 6;              % Rx antenna gain in dB

shadow_dev = 10;      % St.dev of shadowing in dB.

K = 5;                % Rician K factor

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Internal variables.          %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
sum_capacity_rr = zeros(1,length(Cell_users));
sum_capacity_rrpow = zeros(1,length(Cell_users));
sum_capacity_max = zeros(1,length(Cell_users));
sum_capacity_pfs = zeros(1,length(Cell_users));
sum_capacity_pfspow = zeros(1,length(Cell_users));
sum_cap_full_pow = zeros(1,length(Cell_users));
sum_capacity_trad_pfs = zeros(1,length(Cell_users));
sum_capacity_trad_pfspow = zeros(1,length(Cell_users));

avg_syst_cap = zeros(1,length(Cell_users));
avg_syst_cap_full_pow = zeros(1,length(Cell_users));
avg_syst_cap_pfs = zeros(1,length(Cell_users));
avg_syst_cap_pfspow = zeros(1,length(Cell_users));
avg_syst_cap_rr = zeros(1,length(Cell_users));
avg_syst_cap_rrpow = zeros(1,length(Cell_users));
avg_syst_cap_trad_pfs = zeros(1,length(Cell_users));
avg_syst_cap_trad_pfspow = zeros(1,length(Cell_users));

number_cand_rrpow = zeros(length(Cell_users),3);
number_cand_max = zeros(length(Cell_users),3);
number_cand_pfspow = zeros(length(Cell_users),3);
number_cand_trad_pfspow = zeros(length(Cell_users),3);

freq_cand_rrpow = zeros(length(Cell_users),3);
freq_cand_max = zeros(length(Cell_users),3);
freq_cand_pfspow = zeros(length(Cell_users),3);
freq_cand_trad_pfspow = zeros(length(Cell_users),3);

cap_max = zeros(number_simulations,2);
cap_pfs = zeros(number_simulations,2);
cap_pfsp = zeros(number_simulations,2);
cap_trad_pfs = zeros(number_simulations, 2);
cap_trad_pfsp = zeros(number_simulations, 2);

cand = zeros(1,3);

g = 1;
allocDiff = zeros(1,10);
allocMaxCapPos = zeros(1,8);
allocPFSPos = zeros(1,8);

%For U1=U2=1
%capacity_1_1_pow_ad = zeros(1,number_simulations);
%capacity_1_1_full_pow = zeros(1,number_simulations);


for j = 1 : 3 : length(Cell_users)
%j=3;
    U1 = Cell_users(j);
    U2 = U1;
    
    T = ones(2,U1);
    Tp = ones(2,U1);
    Tt = ones(2,U1);
    Ttp = ones(2,U1);
    
    %cap1 = zeros(1,U1);
    %cap2 = zeros(1,U2);
    %cap3 = zeros(U1,U2);
    disp(' ');    disp(' ');
    disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%');
    disp('%Starting simulation with parameters:%');
    disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%');
    disp(['Number of simulations: ', num2str(number_simulations)]);
    disp(['# Users in cell 1: ', num2str(U1)]);
    disp(['# Users in cell 2: : ', num2str(U2)]);
    disp(['P_min: ', num2str(P_min)]);
    disp(['P_max: ', num2str(P_max)]);

    
    for i = 1 : number_simulations
        [G_cell_1 G_cell_2 sig1 sig2] = calc_prop_hex(U1, U2, cell_radius, f_c, terminal_height, BS_height, Grx, Gtx, shadow_dev, exclude_disc_radius, K);
        
        %%% Round Robin with power control
        pos=mod(i,U1)+1;
        rrcap1=log2( 1 + (P_max*G_cell_1(1,pos))/(sig1+P_min*G_cell_1(2,pos))) + log2( 1 + (P_min*G_cell_2(2,pos))/(sig2+P_max*G_cell_2(1,pos)));
        rrcap2=log2( 1 + (P_min*G_cell_1(1,pos))/(sig1+P_max*G_cell_1(2,pos))) + log2( 1 + (P_max*G_cell_2(2,pos))/(sig2+P_min*G_cell_2(1,pos)));
        rrcap3=log2( 1 + (P_max*G_cell_1(1,pos))/(sig1+P_max*G_cell_1(2,pos))) + log2( 1 + (P_max*G_cell_2(2,pos))/(sig2+P_max*G_cell_2(1,pos)));
        
        [tmp_value, tmp_index] = max([rrcap1 rrcap2 rrcap3]);
        sum_capacity_rrpow(j) = sum_capacity_rrpow(j) + tmp_value;
        number_cand_rrpow(j,tmp_index) = number_cand_rrpow(j,tmp_index) + 1;

        %%% Round Robin without power control
        sum_capacity_rr(j) = sum_capacity_rr(j) + rrcap3;
        
        %%% Maximum capacity scheduling
        %For a given set of users, gains, match the optimal users and power levels.
%         maxcap1 = max(log2( 1 + (P_max*G_cell_1(1,:))/sig1 ));
%         maxcap2 = max(log2( 1 + (P_max*G_cell_2(2,:))/sig2 ));
        maxcap1_tmp=zeros(1,U1);
        maxcap2_tmp=zeros(1,U1);
        maxcap3_tmp=zeros(1,U1);
        maxind_tmp=zeros(3,U1);
        
        for u1 = 1 : U1
            [maxcap1_tmp(u1), maxind_tmp(1,u1)] = max(log2( 1 + (P_max*G_cell_1(1,u1))./(sig1+P_min*G_cell_1(2,u1))) + log2( 1 + (P_min*G_cell_2(2,:))./(sig2+P_max*G_cell_2(1,:))));
            [maxcap2_tmp(u1), maxind_tmp(2,u1)] = max(log2( 1 + (P_min*G_cell_1(1,u1))./(sig1+P_max*G_cell_1(2,u1))) + log2( 1 + (P_max*G_cell_2(2,:))./(sig2+P_min*G_cell_2(1,:))));         
            [maxcap3_tmp(u1), maxind_tmp(3,u1)] = max(log2( 1 + (P_max*G_cell_1(1,u1))./(sig1+P_max*G_cell_1(2,u1))) + log2( 1 + (P_max*G_cell_2(2,:))./(sig2+P_max*G_cell_2(1,:))));
        end

        [maxcap1, maxind(1)] = max(maxcap1_tmp);
        [maxcap2, maxind(2)] = max(maxcap2_tmp);
        [maxcap3, maxind(3)] = max(maxcap3_tmp);
        
        %Keep track of solutions
        [tmp_value, tmp_index] = max([maxcap1 maxcap2 maxcap3]);
        sum_capacity_max(j) = sum_capacity_max(j) + tmp_value;
        number_cand_max(j,tmp_index) = number_cand_max(j,tmp_index) + 1;
        
        maxuser1=maxind(tmp_index);
        maxuser2=maxind_tmp(tmp_index,maxuser1);
        
        switch tmp_index
            case 1
                cap=[log2( 1 + (P_max*G_cell_1(1,maxuser1))./(sig1+P_min*G_cell_1(2,maxuser1))), log2( 1 + (P_min*G_cell_2(2,maxuser2))./(sig2+P_max*G_cell_2(1,maxuser2)))];
            case 2
                cap=[log2( 1 + (P_min*G_cell_1(1,maxuser1))./(sig1+P_max*G_cell_1(2,maxuser1))), log2( 1 + (P_max*G_cell_2(2,maxuser2))./(sig2+P_min*G_cell_2(1,maxuser2)))];
            case 3
                cap=[log2( 1 + (P_max*G_cell_1(1,maxuser1))./(sig1+P_max*G_cell_1(2,maxuser1))), log2( 1 + (P_max*G_cell_2(2,maxuser2))./(sig2+P_max*G_cell_2(1,maxuser2)))];
        end
        
        cap_max(i,:) = cap;

        %%% Proportional fair scheduling
        [pfs_val(1), pfs_ind(1)] = max(log2( 1 + (P_max*G_cell_1(1,:))./(sig1+P_max*G_cell_1(2,:)))./Tt(1,:));
        [pfs_val(2), pfs_ind(2)] = max(log2( 1 + (P_max*G_cell_2(2,:))./(sig1+P_max*G_cell_2(1,:)))./Tt(2,:));
        % rate calculation
        rate(1) = pfs_val(1)*Tt(1,pfs_ind(1));
        rate(2) = pfs_val(2)*Tt(2,pfs_ind(2));
        % updating T_k[i+1]
        Tt = (1-1/ic)*Tt;
        Tt(1,pfs_ind(1)) = Tt(1,pfs_ind(1)) + (1/ic)*rate(1);
        Tt(2,pfs_ind(2)) = Tt(2,pfs_ind(2)) + (1/ic)*rate(2);
        
        sum_capacity_trad_pfs(j) = sum_capacity_trad_pfs(j) + sum(rate);
        cap_trad_pfs(i,:) = rate;
        
        %%% Proportional fair scheduling with power control
        %1: P_max 2: P_min
        [pfs_val(1), pfs_ind(1)] = max(log2( 1 + (P_max*G_cell_1(1,:))./(sig1+P_min*G_cell_1(2,:)))./Ttp(1,:));
        [pfs_val(2), pfs_ind(2)] = max(log2( 1 + (P_min*G_cell_2(2,:))./(sig1+P_max*G_cell_2(1,:)))./Ttp(2,:));
        %1: P_min 2: P_max
        [pfs_val(3), pfs_ind(3)] = max(log2( 1 + (P_min*G_cell_1(1,:))./(sig1+P_max*G_cell_1(2,:)))./Ttp(1,:));
        [pfs_val(4), pfs_ind(4)] = max(log2( 1 + (P_max*G_cell_2(2,:))./(sig1+P_min*G_cell_2(1,:)))./Ttp(2,:));
        %1: P_max 2: P_max
        [pfs_val(5), pfs_ind(5)] = max(log2( 1 + (P_max*G_cell_1(1,:))./(sig1+P_max*G_cell_1(2,:)))./Ttp(1,:));
        [pfs_val(6), pfs_ind(6)] = max(log2( 1 + (P_max*G_cell_2(2,:))./(sig1+P_max*G_cell_2(1,:)))./Ttp(2,:));
        
        [tmp_value, tmp_index] = max([pfs_val(1)+pfs_val(2) pfs_val(3)+pfs_val(4) pfs_val(5)+pfs_val(6)]);
        
        switch tmp_index
            case 1
                user1=pfs_ind(1);
                user2=pfs_ind(2);
                cap=[log2( 1 + (P_max*G_cell_1(1,user1))./(sig1+P_min*G_cell_1(2,user1))), log2( 1 + (P_min*G_cell_2(2,user2))./(sig2+P_max*G_cell_2(1,user2)))];
            case 2
                user1=pfs_ind(3);
                user2=pfs_ind(4);
                cap=[log2( 1 + (P_min*G_cell_1(1,user1))./(sig1+P_max*G_cell_1(2,user1))), log2( 1 + (P_max*G_cell_2(2,user2))./(sig2+P_min*G_cell_2(1,user2)))];
            case 3
                user1=pfs_ind(5);
                user2=pfs_ind(6);
                cap=[log2( 1 + (P_max*G_cell_1(1,user1))./(sig1+P_max*G_cell_1(2,user1))), log2( 1 + (P_max*G_cell_2(2,user2))./(sig2+P_max*G_cell_2(1,user2)))];
        end
        
        % updating T_k[i+1]
        Ttp = (1-1/ic)*Ttp;
        Ttp(1,user1) = Ttp(1,user1) + (1/ic)*cap(1);
        Ttp(2,user2) = Ttp(2,user2) + (1/ic)*cap(2);
        
        sum_capacity_trad_pfspow(j) = sum_capacity_trad_pfspow(j) + sum(cap);
        number_cand_trad_pfspow(j,tmp_index) = number_cand_trad_pfspow(j,tmp_index) + 1;
        cap_trad_pfsp(i,:) = cap;
        
        %%% Joint proportional fair scheduling without power control
        pfs_val=zeros(1,U1);
        pfs_ind=zeros(1,U1);
        
        % finding k* = argmax_k R_[k]/T_k[i]
        for u1 = 1 : U1
            [pfs_val(u1), pfs_ind(u1)] = max( log2( 1 + (P_max*G_cell_1(1,u1))./(sig1+P_max*G_cell_1(2,u1)))/T(1,u1) + log2( 1 + (P_max*G_cell_2(2,:))./(sig2+P_max*G_cell_2(1,:)))./T(2,:));
        end
        
        [tradcap, tradind] = max(pfs_val);
        pfs_user1=tradind;
        pfs_user2=pfs_ind(tradind);
        
        %rate calculation
        rate=[log2( 1 + (P_max*G_cell_1(1,pfs_user1))./(sig1+P_max*G_cell_1(2,pfs_user1))), log2( 1 + (P_max*G_cell_2(2,pfs_user2))./(sig2+P_max*G_cell_2(1,pfs_user2)))];
        
        %updating T_k[i+1]
        T = (1-1/ic)*T;
        T(1,pfs_user1) = T(1,pfs_user1) + (1/ic)*rate(1);
        T(2,pfs_user2) = T(2,pfs_user2) + (1/ic)*rate(2);
        
        sum_capacity_pfs(j) = sum_capacity_pfs(j) + sum(rate);
        cap_pfs(i,:) = rate;
        
        %%% Joint proportional fair scheduling with power control
        % find the capacity for the different users
        pfscap_tmp=zeros(3,U1);
        pfscap_ind=zeros(3,U1);
        
        for u1 = 1 : U1
            [pfscap_tmp(1,u1), pfscap_ind(1,u1)] = max(log2( 1 + (P_max*G_cell_1(1,u1))./(sig1+P_min*G_cell_1(2,u1)))/Tp(1,u1) + log2( 1 + (P_min*G_cell_2(2,:))./(sig2+P_max*G_cell_2(1,:)))./Tp(2,:));
            [pfscap_tmp(2,u1), pfscap_ind(2,u1)] = max(log2( 1 + (P_min*G_cell_1(1,u1))./(sig1+P_max*G_cell_1(2,u1)))/Tp(1,u1) + log2( 1 + (P_max*G_cell_2(2,:))./(sig2+P_min*G_cell_2(1,:)))./Tp(2,:));         
            [pfscap_tmp(3,u1), pfscap_ind(3,u1)] = max(log2( 1 + (P_max*G_cell_1(1,u1))./(sig1+P_max*G_cell_1(2,u1)))/Tp(1,u1) + log2( 1 + (P_max*G_cell_2(2,:))./(sig2+P_max*G_cell_2(1,:)))./Tp(2,:));
        end

        [pfscap(1), pfsind(1)] = max(pfscap_tmp(1,:));
        [pfscap(2), pfsind(2)] = max(pfscap_tmp(2,:));
        [pfscap(3), pfsind(3)] = max(pfscap_tmp(3,:));
        
        %Keep track of solutions
        [tmp_value2, tmp_index2] = max(pfscap);
        
        user1=pfsind(tmp_index2);
        user2=pfscap_ind(tmp_index2,pfsind(tmp_index2)); 
        
        switch tmp_index2
            case 1
                cap=[log2( 1 + (P_max*G_cell_1(1,user1))./(sig1+P_min*G_cell_1(2,user1))), log2( 1 + (P_min*G_cell_2(2,user2))./(sig2+P_max*G_cell_2(1,user2)))];
            case 2
                cap=[log2( 1 + (P_min*G_cell_1(1,user1))./(sig1+P_max*G_cell_1(2,user1))), log2( 1 + (P_max*G_cell_2(2,user2))./(sig2+P_min*G_cell_2(1,user2)))];
            case 3
                cap=[log2( 1 + (P_max*G_cell_1(1,user1))./(sig1+P_max*G_cell_1(2,user1))), log2( 1 + (P_max*G_cell_2(2,user2))./(sig2+P_max*G_cell_2(1,user2)))];
        end
        
        tp_old(1) = Tp(1,user1);
        tp_old(2) = Tp(2,user2);
        
        % Update T_k[i+1]
        Tp = (1-1/ic)*Tp;
        Tp(1,user1) = Tp(1,user1) + (1/ic)*cap(1);
        Tp(2,user2) = Tp(2,user2) + (1/ic)*cap(2);
                
        
        sum_capacity_pfspow(j) = sum_capacity_pfspow(j) + sum(cap);
        number_cand_pfspow(j,tmp_index2) = number_cand_pfspow(j,tmp_index2) + 1;
        cap_pfsp(i,:) = cap;
        
        %%% Full power allocation
        sum_cap_full_pow(j) = sum_cap_full_pow(j) + maxcap3;
        
        %%% Storing "odd" results
%         if tmp_index ~= tmp_index2
% %             disp(' ');
% %             disp(['Odd results at j=', num2str(j), ' and i=', num2str(i)]);
% %             disp(['Max-Cap users: (', num2str(maxuser1), ', ', num2str(maxuser2), ')']);
% %             disp(['1: x-pos: ', num2str(user_loc_cell_1(1,maxuser1)), ' y-pos: ', num2str(user_loc_cell_1(2,maxuser1))]);
% %             disp(['2: x-pos: ', num2str(user_loc_cell_2(1,maxuser2)), ' y-pos: ', num2str(user_loc_cell_2(2,maxuser2))]);
% %             disp(['PFS users: (', num2str(pfs_user1), ', ', num2str(pfs_user2), ') and rate: ', num2str(sum(rate))]);
% %             disp(['PFS-P users: (', num2str(user1), ', ', num2str(user2), ')']);
% %             disp(['1: x-pos: ', num2str(user_loc_cell_1(1,user1)), ' y-pos: ', num2str(user_loc_cell_1(2,user1))]);
% %             disp(['2: x-pos: ', num2str(user_loc_cell_2(1,user2)), ' y-pos: ', num2str(user_loc_cell_2(2,user2))]);
% %             disp(['PFS metric - 1: ', num2str(pfscap(1)), ' 2: ', num2str(pfscap(2)), ' 3: ', num2str(pfscap(3))]);
% %             disp(['Max-Cap: ', num2str(tmp_value), ' (', num2str(tmp_index), ')', ' PFS: ', num2str(sum(cap)), ' (', num2str(tmp_index2), ')']);
%             
%             allocDiff(g, :) = [j i tmp_index tmp_value tmp_index2 sum(cap) tp_old(1) tp_old(2) Tp(1,user1) Tp(2,user2)];
%             allocMaxCapPos(g, :) = [j i maxuser1 user_loc_cell_1(1,maxuser1) user_loc_cell_1(2, maxuser1) maxuser2 user_loc_cell_2(1,maxuser2) user_loc_cell_2(2,maxuser2)];
%             allocPFSPos(g, :) = [j i user1 user_loc_cell_1(1,user1) user_loc_cell_1(2,user1) user2 user_loc_cell_2(1,user2) user_loc_cell_2(2,user2)];
%             g = g + 1;
% 
%         end
        
   
    end %for loop number of iterations.

    g = g + 1;

    %%%%%%%%%%%%%%%%%%%%%%
    % Preparing results. %
    %%%%%%%%%%%%%%%%%%%%%%
    avg_syst_cap(j) = sum_capacity_max(j)/number_simulations;
    avg_syst_cap_full_pow(j) = sum_cap_full_pow(j)/number_simulations;
    avg_syst_cap_rr(j) = sum_capacity_rr(j)/number_simulations;
    avg_syst_cap_rrpow(j) = sum_capacity_rrpow(j)/number_simulations;
    avg_syst_cap_pfs(j) = sum_capacity_pfs(j)/number_simulations;
    avg_syst_cap_pfspow(j) = sum_capacity_pfspow(j)/number_simulations;
    avg_syst_cap_trad_pfs(j) = sum_capacity_trad_pfs(j)/number_simulations;
    avg_syst_cap_trad_pfspow(j) = sum_capacity_trad_pfspow(j)/number_simulations;
    % number_cand
    freq_cand_rrpow(j,:) = (number_cand_rrpow(j,:)/number_simulations)*100;
    freq_cand_max(j,:) = (number_cand_max(j,:)/number_simulations)*100;
    freq_cand_pfspow(j,:) = (number_cand_pfspow(j,:)/number_simulations)*100;
    freq_cand_trad_pfspow(j,:) = (number_cand_pfspow(j,:)/number_simulations)*100;

    
    disp(' ');disp(' ');
    disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%');
    disp('%       Simulation finished!         %');
    disp('%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%');

    %disp(['Sum_capacity: ', num2str(sum_capacity)]);
    disp(['Avg. system capacity, max: ', num2str(avg_syst_cap_full_pow(j))]);
    disp(['Avg. system capacity, max pow.ad: ', num2str(avg_syst_cap(j))]);
    disp(['Avg. system capacity, rr: ', num2str(avg_syst_cap_rr(j))]);
    disp(['Avg. system capacity, rr pow.ad: ', num2str(avg_syst_cap_rrpow(j))]);
    disp(['Avg. system capacity, trad pfs: ', num2str(avg_syst_cap_trad_pfs(j))]);
    disp(['Avg. system capacity, trad pfs pow.ad: ', num2str(avg_syst_cap_trad_pfspow(j))]);
    disp(['Avg. system capacity, v-pfs: ', num2str(avg_syst_cap_pfs(j))]);
    disp(['Avg. system capacity, v-pfs pow.ad: ', num2str(avg_syst_cap_pfspow(j))]);
    disp(['Frequency of solutions: ']);
    disp(['                 RR          T-PFS       V-PFS         Max']);
    disp(['(P_max,P_min)    ',num2str(freq_cand_rrpow(j,1)),'      ',num2str(freq_cand_trad_pfspow(j,1)),'      ',num2str(freq_cand_pfspow(j,1)),'      ',num2str(freq_cand_max(j,1)),' %.']);
    disp(['(P_min,P_max)    ',num2str(freq_cand_rrpow(j,2)),'      ',num2str(freq_cand_trad_pfspow(j,2)),'      ',num2str(freq_cand_pfspow(j,2)),'      ',num2str(freq_cand_max(j,2)),' %.']);
    disp(['(P_max,P_max)    ',num2str(freq_cand_rrpow(j,3)),'      ',num2str(freq_cand_trad_pfspow(j,3)),'      ',num2str(freq_cand_pfspow(j,3)),'      ',num2str(freq_cand_max(j,3)),' %.']);
    
    directory = 'simul_scheduling/p_min_0/';

%     save([directory, 'allocDiff', num2str(j)], 'allocDiff');
%     save([directory, 'allocMaxCapPos', num2str(j)], 'allocMaxCapPos');
%     save([directory, 'allocPFSPos', num2str(j)], 'allocPFSPos');

    save([directory, 'cap_max', num2str(j)], 'cap_max');
    save([directory, 'cap_pfs', num2str(j)], 'cap_pfs');
    save([directory, 'cap_pfsp', num2str(j)], 'cap_pfsp');
    save([directory, 'cap_trad_pfs', num2str(j)], 'cap_trad_pfs');
    save([directory, 'cap_trad_pfsp', num2str(j)], 'cap_trad_pfsp');

end

toc

%Store results

% save([directory, 'avg_syst_cap'], 'avg_syst_cap');
% save([directory, 'avg_syst_cap_full_pow'], 'avg_syst_cap_full_pow');
% save([directory, 'avg_syst_cap_rr'], 'avg_syst_cap_rr');
% save([directory, 'avg_syst_cap_rrpow'], 'avg_syst_cap_rrpow');
% save([directory, 'avg_syst_cap_pfs'], 'avg_syst_cap_pfs');
% save([directory, 'avg_syst_cap_pfspow'], 'avg_syst_cap_pfspow');
% save([directory, 'avg_syst_cap_trad_pfs'], 'avg_syst_cap_trad_pfs');
% 
% save([directory, 'freq_cand_rrpow'], 'freq_cand_rrpow');
% save([directory, 'freq_cand_max'], 'freq_cand_max');
% save([directory, 'freq_cand_pfspow'], 'freq_cand_pfspow');
